# Install and load the required libraries if you haven't already

library(ggplot2)
library(dplyr)
library(dotenv)
library(here)

load_dot_env()
data_path <- Sys.getenv("DATA_PATH")

# Define paths to cleaned panel A & B data in dropbox (change this)
path_to_A <- here(data_path,"analysis","clean_panel_A_final.csv")
path_to_B <- here(data_path,"analysis","clean_panel_B.csv")
path_to_coefs <- here(data_path,"analysis","coefs_A.csv")
path_to_coefs_B <- here(data_path,"analysis","coefs_B.csv")

# Read in data
panel_A <- read.csv(path_to_A)
panel_B <- read.csv(path_to_B)
coefs_A <-read.csv(path_to_coefs)
coefs_B <-read.csv(path_to_coefs_B)

## Panel A CoefPlot Creation

# Remove 'X', the index which became a separate column
panel_A <- subset(panel_A, select = -X)
panel_A_full <- subset(panel_A, select = -Label)

panel_A_full
# Codify variable names with text
panel_A_full <- panel_A_full %>%
  rename(
    'Housing Expenditures (4-12 months)' = Q9_1_1,
    'Housing Expenditures (12-18 months)' = Q9_2_1,
    'Housing Quality (4-12 months)' = Q10_1_1,
    'Housing Quality (12-18 months)' = Q10_2_1,
    'Household Consumption (12-18 months)' = Q13_1_1,
    'Adult Mental Health (4-12 months)' = Q14_1_1,
    'Adult Mental Health (12-18 months)' = Q14_2_1,
    'Child Socio-Emotional (12-18 months)' = Q15_1_1
  )

# Define the custom order for y-axis labels
custom_y_order <- c(
  
  "Housing Expenditures (12-18 months)",
  "Housing Expenditures (4-12 months)",
  "Housing Quality (12-18 months)",
  "Housing Quality (4-12 months)",
  "Adult Mental Health (12-18 months)", 
  "Adult Mental Health (4-12 months)",
  "Household Consumption (12-18 months)",
  "Child Socio-Emotional (12-18 months)"
)


### PANEL A CODE ###
# Calculate mean for each variable
means_A <- colMeans(panel_A_full)

# Calculate column-wise standard deviations
std_deviations_A <- apply(panel_A_full, 2, sd)


# Calculate percentiles (e.g., 10th and 90th percentiles) for each variable
percentiles_10_A <- apply(panel_A_full, 2, quantile, probs = 0.10)
percentiles_90_A <- apply(panel_A_full, 2, quantile, probs = 0.90)


# Combine mean and percentiles into a dataframe
coef_data_A <- data.frame(
  Variable = names(means_A),
  Mean = means_A,
  Percentile_10 = percentiles_10_A,
  Percentile_90 = percentiles_90_A,
  se = std_deviations_A
)


# Rename variable column
coef_data_A <- coef_data_A %>%
  rename(var_name = Variable)
# Remove row names
rownames(coef_data_A) <- NULL

coefs_P <-coef_data_A

coefs_P$var_name <- paste("Predicted", coefs_P$var_name, sep = " ")
# Add a 'Type' column to coefs_P
coefs_P$Type <- "Prediction"


coefs_P

# Add two columns filled with NA values
coefs_A$Percentile_10 <- rep(NA, nrow(coefs_A))
coefs_A$Percentile_90 <- rep(NA, nrow(coefs_A))
coefs_A$Type <- "Actual"

coefs_A$var_name <- custom_y_order

# 0 out Housing Expenditures (4-12 months) wrt data quality
coefs_A[2,2]<-0
coefs_A[2,3]<-0
coefs_A

coefs_A
# Stack the dataframes on top of each other
combined_df <- rbind(coefs_A, coefs_P)
combined_df


combined_df

# Save the dataframe as a CSV file
write.csv(combined_df, file = here(data_path,"analysis","means_coefs_A.csv"))

#Renaming to match overleaf

# combined_df <- combined_df %>%
#   mutate(var_name = ifelse(var_name == "Household Consumption (12-18 months)", 
#                            "Total Consumption (Endline)", 
#                            var_name))
# combined_df <- combined_df %>%
#   mutate(var_name = ifelse(var_name == "Predicted Household Consumption (12-18 months)", 
#                            "Predicted Total Consumption (Endline)", 
#                            var_name))
# combined_df <- combined_df %>%
#   mutate(var_name = ifelse(var_name == "Housing Quality (12-18 months)", 
#                            "Housing Quality (Endline)", 
#                            var_name))
# combined_df <- combined_df %>%
#   mutate(var_name = ifelse(var_name == "Predicted Housing Quality (12-18 months)", 
#                            "Predicted Housing Quality (Endline)", 
#                            var_name))
# combined_df <- combined_df %>%
#   mutate(var_name = ifelse(var_name == "Housing Quality (4-12 months)", 
#                            "Housing Quality (Midline)", 
#                            var_name))
# combined_df <- combined_df %>%
#   mutate(var_name = ifelse(var_name == "Predicted Housing Quality (4-12 months)", 
#                            "Predicted Housing Quality (Midline)", 
#                            var_name))

combined_df <- combined_df %>%
  mutate(var_name = case_when(
    var_name == "Household Consumption (12-18 months)" ~ "Total Consumption (Endline)",
    var_name == "Predicted Household Consumption (12-18 months)" ~ "Predicted Total Consumption (Endline)",
    var_name == "Housing Quality (12-18 months)" ~ "Housing Quality (Endline)",
    var_name == "Predicted Housing Quality (12-18 months)" ~ "Predicted Housing Quality (Endline)",
    var_name == "Housing Quality (4-12 months)" ~ "Housing Quality (Midline)",
    var_name == "Predicted Housing Quality (4-12 months)" ~ "Predicted Housing Quality (Midline)",
    var_name == "Housing Expenditures (4-12 months)" ~ "Housing Expenditures (Midline)",
    var_name == "Predicted Housing Expenditures (4-12 months)" ~ "Predicted Housing Expenditures (Midline)",
    var_name == "Housing Expenditures (12-18 months)" ~ "Housing Expenditures (Endline)",
    var_name == "Predicted Housing Expenditures (12-18 months)" ~ "Predicted Housing Expenditures (Endline)",
    var_name == "Adult Mental Health (4-12 months)" ~ "Adult Mental Health (Midline)",
    var_name == "Predicted Adult Mental Health (4-12 months)" ~ "Predicted Adult Mental Health (Midline)",
    var_name == "Adult Mental Health (12-18 months)" ~ "Adult Mental Health (Endline)",
    var_name == "Predicted Adult Mental Health (12-18 months)" ~ "Predicted Adult Mental Health (Endline)",
    var_name == "Child Socio-Emotional (12-18 months)" ~ "Child Socio-Emotional (Endline)",
    var_name == "Predicted Child Socio-Emotional (12-18 months)" ~ "Predicted Child Socio-Emotional (Endline)",
    TRUE ~ var_name
  ))



# Create a mapping between var_name and numeric y_position values for custom spacing
# spacing_mapping <- c(
#   "Predicted Child Socio-Emotional (12-18 months)" = 1,
#   "Child Socio-Emotional (12-18 months)" = 1.25,
#   "Predicted Adult Mental Health (12-18 months)" = 1.75,
#   "Adult Mental Health (12-18 months)" = 2,
#   "Predicted Adult Mental Health (4-12 months)" = 2.5,
#   "Adult Mental Health (4-12 months)" = 2.75,
#   "Predicted Total Consumption (12-18 months)" = 3.25,
#   "Total Consumption (12-18 months)" = 3.5,
#   "Predicted Housing Expenditures (12-18 months)" = 4,
#   "Housing Expenditures (12-18 months)" = 4.25,
#   "Predicted Housing Expenditures (4-12 months)" = 4.75,
#   "Housing Expenditures (4-12 months)" = 5,
#   "Predicted Housing Quality (12-18 months)" = 5.5,
#   "Housing Quality (12-18 months)" = 5.75,
#   "Predicted Housing Quality (4-12 months)" = 6.25,
#   "Housing Quality (4-12 months)" = 6.5
# )

spacing_mapping <- c(
  "Predicted Child Socio-Emotional (Endline)" = 1,
  "Child Socio-Emotional (Endline)" = 1.25,
  "Predicted Adult Mental Health (Endline)" = 1.75,
  "Adult Mental Health (Endline)" = 2,
  "Predicted Adult Mental Health (Midline)" = 2.5,
  "Adult Mental Health (Midline)" = 2.75,
  "Predicted Total Consumption (Endline)" = 3.25,
  "Total Consumption (Endline)" = 3.5,
  "Predicted Housing Expenditures (Endline)" = 4,
  "Housing Expenditures (Endline)" = 4.25,
  "Predicted Housing Expenditures (Midline)" = 4.75,
  "Housing Expenditures (Midline)" = 5,
  "Predicted Housing Quality (Endline)" = 5.5,
  "Housing Quality (Endline)" = 5.75,
  "Predicted Housing Quality (Midline)" = 6.25,
  "Housing Quality (Midline)" = 6.5
)




# Add the y_position column for custom spacing
combined_df <- combined_df %>%
  mutate(y_position = spacing_mapping[var_name])

# #Renaming to match overleaf
# 
# combined_df <- combined_df %>%
#   mutate(var_name = ifelse(var_name == "Household Consumption (12-18 months)", 
#                            "Total Consumption (12-18 months)", 
#                            var_name))
# combined_df <- combined_df %>%
#   mutate(var_name = ifelse(var_name == "Predicted Household Consumption (12-18 months)", 
#                            "Predicted Total Consumption (12-18 months)", 
#                            var_name))

## Housing expenditures (4-12 months) actual 0 out?

combined_df <- combined_df[combined_df$Mean != 0, ]

## Replace Actual with Estimate

combined_df <- combined_df %>%
  mutate(Type = if_else(Type == "Actual", "Estimate", Type))


# Create a ggplot with custom column order and custom spacing
coefficient_plot_custom_spacing <- ggplot(data = combined_df, aes(x = Mean, y = y_position, color = Type, shape = Type)) +
  geom_point(size = 3) +
  geom_errorbarh(data = combined_df[combined_df$Type == "Estimate",],
                 aes(xmin = ifelse(is.na(se), Mean - 1.96 * se, Mean - 1.96 * se),
                     xmax = ifelse(is.na(se), Mean + 1.96 * se, Mean + 1.96 * se)),
                 height = 0.1) +
  geom_errorbarh(data = combined_df[combined_df$Type == "Prediction", ],
                 aes(xmin = Percentile_10, xmax = Percentile_90),
                 height = 0.1, color = "blue") +
  geom_vline(xintercept = 0, linetype = "dashed", color = "black") +
  geom_vline(xintercept = -0.25, linetype='dashed',  color = "grey") +
  geom_vline(xintercept = 0.25, linetype='dashed', color = "grey") +
  labs(
    title = "",
    x = "Change in SD",
    y = NULL
  ) +
  theme_minimal() +
  scale_color_manual(values = c("Estimate" = "red", "Prediction" = "blue")) +
  scale_shape_manual(values = c("Estimate" = 16, "Prediction" = 15)) +
  scale_y_continuous(breaks = spacing_mapping[c(FALSE, TRUE)], labels = names(spacing_mapping[c(FALSE, TRUE)])) +  # Set custom y-axis positions and labels
  xlim(-1.2, 1.2) +
  theme(
    axis.text.y = element_text(face = "bold",vjust = 0.5),  # Adjust the vertical alignment of labels
    plot.title = element_text(hjust = 0.5),
    legend.title = element_blank(),
    legend.text = element_text(face = "bold"),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.grid.major.y = element_blank(),
    axis.text.x = element_text(face = "bold", vjust = -0.5)) + 
  scale_x_continuous(breaks = seq(-1, 1, 0.25))+
  coord_cartesian(xlim = c(-1.2, 1.2))
#annotate("text", x = 0.0, y = 5, label = "X", size = 4) 
#annotate("text", x = 0.6, y = 2, label = 'Note: Actual 95% CI, \n Prediction P10-P90', size = 3, hjust = 0, vjust = 1)
# Add the desired x-axis labels

# Increase the font size of the y-axis labels / left-alignment
coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  theme(axis.text.y = element_text(size = 13, face = "bold", colour = "black", hjust = 0)) +
  theme(axis.title.y = element_text(vjust = 0.5))  # Adjust the font size 

# # Increase the font size of the y-axis labels / right-alignment 
# coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
#   theme(axis.text.y = element_text(size = 14, face = "bold", colour = "black", hjust = 1.0)) +
#   theme(axis.title.y = element_text(vjust = 0.5))  # Adjust the font size 

# Increase the font size of the legend
coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  theme(legend.text = element_text(size = 12))  # Adjust the font size (12 is just an example, use your desired size)
# Adding star manually
coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  geom_text(aes(x = 0.5, y = 1.2, label = "*"), color = "black", size = 5, fontface = "bold")  
coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  geom_text(aes(x = 0.5, y = 4.2, label = "*"), color = "black", size = 5, fontface = "bold") 

## Adjusting the x-axis
coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  coord_cartesian(xlim = c(-1.2, 1.2)) +
  scale_x_continuous(breaks = c(-1.00, -0.75, -0.50, -0.25, 0, 0.25, 0.50, 0.75, 1.00))


## To save it in to Dropbox or preffered location:
ggsave("results/figures/Fig3_PanelA.png", coefficient_plot_custom_spacing, width = 10, height = 6, bg = "white")


# Print the combined plot with custom spacing just to see it here:
# print(coefficient_plot_custom_spacing)