library(ggplot2)
library(dplyr)
library(dotenv)
library(here)

load_dot_env()
data_path <- Sys.getenv("DATA_PATH")



# Define paths to cleaned panel A & B data in dropbox (change this)
#path_to_B <- "/Users/peter-evoy/S-RLS (UC Berkeley) Dropbox/Peter Grinde-Hollevik/Prediction/Round 2/clean_panel_B.csv"
#path_to_coefs_B <- "/Users/peter-evoy/S-RLS (UC Berkeley) Dropbox/Peter Grinde-Hollevik/Prediction/Round 2/coefs_B.csv"
path_to_B <- here(data_path,"analysis","clean_panel_B.csv")
path_to_coefs_B <- here(data_path,"analysis","coefs_B.csv")



# Read in data
panel_B <- read.csv(path_to_B)
coefs_A <-read.csv(path_to_coefs_B)
panel_B <- subset(panel_B, select = -X)
panel_B <- subset(panel_B, select = -C)

panel_B

panel_B <- panel_B %>%
  rename(
    'Policy Support' = Q21_1,
    'Economic Perception' = Q20_1,
    'Social Attitudes' = Q19_1
  )

# Check for the number of NaN values in panel_B
num_nans <- sum(is.na(panel_B), na.rm = TRUE) # We have 31 rows with nans - resulting change from 87 to 63 observations.

# Print the result
cat("Number of NaN values in panel_B:", num_nans, "\n") #31 in total

# Remove rows with NaN values from panel_B
panel_B_clean <- na.omit(panel_B)

panel_B_clean


# Calculate mean for each variable
means_B <- colMeans(panel_B_clean)
# Calculate column-wise standard deviations
std_deviations_B <- apply(panel_B_clean, 2, sd)

# Calculate percentiles (e.g., 10th and 90th percentiles) for each variable
percentiles_10_B <- apply(panel_B_clean, 2, quantile, probs = 0.10)
percentiles_90_B <- apply(panel_B_clean, 2, quantile, probs = 0.90)


# Combine mean and percentiles into a dataframe for predictions
coefs_P <- data.frame(
  var_name = names(means_B),
  se = std_deviations_B,
  Mean = means_B,
  Percentile_10 = percentiles_10_B,
  Percentile_90 = percentiles_90_B
)
# Add predicted to title
coefs_P$var_name <- paste("Predicted", coefs_P$var_name, sep = " ")
# Add a 'Type' column to coefs_P
coefs_P$Type <- "Prediction"
rownames(coefs_P)<-NULL
coefs_P
# Save the dataframe as a CSV file
# write.csv(coefs_P, file = here(data_path,"analysis","prediction_means_panel_B.csv"))

# Prep actual coefficients dataframe for combination
coefs_A
# Add two columns filled with NA values
coefs_A$Percentile_10 <- rep(NA, nrow(coefs_A))
coefs_A$Percentile_90 <- rep(NA, nrow(coefs_A))
coefs_A$Type <- "Actual"

coefs_A

# Stack the dataframes on top of each other
combined_df <- rbind(coefs_A, coefs_P)
combined_df

# Save the dataframe as a CSV file
write.csv(combined_df, file = here(data_path,"analysis","means_coefs_B.csv"))


# Create a mapping between var_name and numeric y_position values for custom spacing without Dummy1
spacing_mapping <- c(
  "Predicted Social Attitudes" = 1.5,
  "Social Attitudes" = 1.6,
  "Predicted Economic Perception" = 1.8,
  "Economic Perception" = 1.9,
  "Predicted Policy Support" = 2.1,
  "Policy Support" = 2.2
  
)
## Creating Dummy Variable to make the y-axis label gap narrower

dummy_row <- data.frame(
  var_name = c("Dummy1"),
  Mean = rep(NA, 1),  # Assuming the dummy rows have NA for Mean
  se = rep(NA, 1),    # Assuming the dummy rows have NA for se
  Percentile_10 = rep(NA, 1),
  Percentile_90 = rep(NA, 1),
  Type = rep(NA, 1),  # Assuming the dummy rows have NA for Type
  y_position = c(2.35)
)

# Add the y_position column for custom spacing without Dummy1
combined_df <- combined_df %>%
  mutate(y_position = spacing_mapping[var_name])

# Bind the dummy row to combined_df
combined_df <- rbind(combined_df, dummy_row)

# Create a mapping between var_name and numeric y_position values for custom spacing with Dummy1
spacing_mapping <- c(
  "Predicted Social Attitudes" = 1.5,
  "Social Attitudes" = 1.6,
  "Predicted Economic Perception" = 1.8,
  "Economic Perception" = 1.9,
  "Predicted Policy Support" = 2.1,
  "Policy Support" = 2.2,
  "Dummy1" = 3.6
  
)


# Add the y_position column for custom spacing with Dummy1
combined_df <- combined_df %>%
  mutate(y_position = spacing_mapping[var_name])

# Create a ggplot with custom column order and custom spacing
coefficient_plot_custom_spacing <- ggplot(data = combined_df, aes(x = Mean, y = y_position, color = Type, shape = Type)) +
  geom_point(size = 3) +
  geom_errorbarh(data = combined_df[combined_df$Type != "Prediction",],
                 aes(xmin = ifelse(is.na(se), Mean - 1.96 * se, Mean - 1.96 * se),
                     xmax = ifelse(is.na(se), Mean + 1.96 * se, Mean + 1.96 * se)),
                 height = 0.04) +
  geom_errorbarh(data = combined_df[combined_df$Type == "Prediction", ],
                 aes(xmin = Percentile_10, xmax = Percentile_90),
                 height = 0.04, color = "blue") +
  geom_vline(xintercept = 0, linetype = "dashed", color = "black") +
  geom_vline(xintercept = -0.25, linetype='dashed',  color = "grey") +
  geom_vline(xintercept = 0.25, linetype='dashed', color = "grey") +
  labs(
    title = "",
    x = "Change in SD",
    y = NULL
  ) +
  theme_minimal() +
  scale_color_manual(values = c("Actual" = "red", "Prediction" = "blue"), na.translate = FALSE) +
  scale_shape_manual(values = c("Actual" = 16, "Prediction" = 15), na.translate = FALSE) +
  scale_y_continuous(breaks = spacing_mapping[c(FALSE, TRUE)], labels = names(spacing_mapping[c(FALSE, TRUE)])) +  # Set custom y-axis positions and labels
  xlim(-1.2, 1.2) +
  theme(
    axis.text.y = element_text(vjust = 0.5, face = "bold", color = "black"),  # Adjust the vertical alignment of labels
    plot.title = element_text(hjust = 0.5, face = "bold"),
    legend.title = element_blank(),
    legend.text = element_text(face = "bold"),
    panel.grid.major = element_blank(),
    panel.grid.minor = element_blank(),
    panel.grid.major.y = element_blank())
# Add the N value as an annotation
#annotate("text", x = 0.7, y = 2.4, label = paste("n =", 1715), color = "red", size = 3) +
#annotate("text", x = 0.55, y = 2.3, label = paste("n =", 63), color = "blue", size = 3)

# Increase the font size of the y-axis labels
coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  theme(axis.text.y = element_text(size = 12, face = "bold", colour = "black", hjust = 0.5)) +
  theme(axis.title.y = element_text(vjust = 0.5))  # Adjust the font size 

# Adding star manually
coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  geom_text(aes(x = 0.5, y = 1.6, label = "*"), color = "black", size = 5, fontface = "bold") 


## Adjusting the x-axis
coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  coord_cartesian(xlim = c(-1.2, 1.2)) +
  scale_x_continuous(breaks = c(-1.00, -0.75, -0.50, -0.25, 0, 0.25, 0.50, 0.75, 1.00))

coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  theme(axis.text.x = element_text(face = "bold"))


# Adjusting the legend
coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  theme(
    legend.position = c(1.01, 0.19),
    legend.text = element_text(size = 11), # Increase text size
    legend.key.size = unit(1.2, "lines")   # Increase symbol size
  )

# Adjusting the y-axis labels (left-alignment)
coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  theme(
    axis.text.y = element_text(size = 12, face = "bold", color = "black", hjust = 0)
  )
coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  theme(axis.text.y = element_text(margin = margin(t = 0, r = 87, b = 0, l = 0)))

# Adjusting the y-axis labels right-alignment (if left desired comment it out: you can use Cmd+Shift+C on mac)
# coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
#   theme(
#     axis.text.y = element_text(size = 12, face = "bold", color = "black", hjust = 1.0)
#   )
# coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
#   theme(axis.text.y = element_text(margin = margin(t = 0, r = 5, b = 0, l = 0)))



# Changing aspect ratio To Match Panel A plot
coefficient_plot_custom_spacing <- coefficient_plot_custom_spacing +
  theme(aspect.ratio = 1/1.07)

# Saving as a .png into dropbox or preferred file path:
ggsave("results/figures/Fig3_PanelB.png", coefficient_plot_custom_spacing, width = 10, height = 6, bg = "white")

#ggsave("/Users/hasanebussuutoglu/Dropbox/S-RLS/coefplotB#.png", coefficient_plot_custom_spacing, width = 10, height = 6, bg = "white")

# Print the combined plot with custom spacing to see it here:
print(coefficient_plot_custom_spacing)