*-------------------------------------------------------------------------------
* TABLE1. BALANCE TABLE
*-------------------------------------------------------------------------------

/*
NOTES/QUESTIONS:

	- Original do file path: /Users/eithandarmyint/Library/CloudStorage/Dropbox/GitHub/S-RLS/RCT/Phone Survey/4. Analyze/code/main/balance.do

	*** For PS_controls.dta construction:
	- 1. When constructing PS_controls.dta, make sure to include the two rename lines in the chunk below (to be able to merge cleanly without using the force option)
	- 2. Also, fix inconsistencies in localities in PS_controls.dta construction so that this do file can just be for analysis.
	- 3. Make sure every variable has labels. 

*/

clear all
set more off
program drop _all
set maxvar 10000

* ---------------------------------------------------------------------
* Setup project directory
*	- Uses 'project' to setup project directory 
* 	- Runs project setup directives in "$project_dir/code/do/setup/project_setup.do"
* ---------------------------------------------------------------------
capture project, doinfo
if _rc==0{
	global project_dir "`r(pdir)'"
}
else{
	project srls_analysis, cd
	global project_dir "`c(pwd)'"	
	do "`c(pwd)'/code/do/setup/disable_project.do"
}

do "$project_dir/code/do/setup/project_setup.do"

/*
*-------------------------------------------------------------------------------
* MODIFY THE DATASETS TO BE ABLE TO MERGE CLEANLY
*-------------------------------------------------------------------------------

* Controls dataset
use "/Users/eithandarmyint/Dropbox/S-RLS Data/RCT/2021 - Phone Survey/outcomes/PS_controls.dta", clear 

* Rename district and locality
ren district district_name
ren locality locality_name

save "$da/PS_controls_clean.dta", replace 
*/

*-------------------------------------------------------------------------------
* MERGE THE DATASETS 
*-------------------------------------------------------------------------------


* Controls dataset
project, original("$da/PS_controls.dta")
use "$da/PS_controls.dta", clear 

* Rename district and locality
ren district district_name
ren locality locality_name

save "$da/PS_controls_clean.dta", replace 
project, creates("$da/PS_controls_clean.dta")


* All outcomes dataset
project, original("$da/PS_all_outcomes.dta")
use "$da/PS_all_outcomes.dta", clear


* Merge with controls dataset
project, uses("$da/PS_controls_clean.dta") preserve
merge 1:1 Key_USE using "$da/PS_controls_clean", nogen 

* Fix inconsistencies in localities
replace LocalityName="Mansoorah (Dair Al Kahf)" if locality==571 &	LocalityName=="Mansoorah"
replace LocalityName="Mansoorah (Gharbiyah)" if locality==586 &	LocalityName=="Mansoorah"
replace LocalityName="Zuhoor (Mafraq)" if locality==461 &	LocalityName=="Zuhoor"
replace locality=302 if LocalityName=="Alhusban"
replace locality=302 if LocalityName=="Alrabya"

drop district subdistrict Governorate_rand mafraq irbid

* Merge with localities dataset
project, uses("$da/PS_controls_clean.dta") preserve
merge m:1 LocalityName locality using "$da/localities.dta"

drop if _merge==2
drop locality

rename order locality 
	label define treat 0 "Control" 1 "Treat"
	label val assign_flex treat
	label val assign_re treat
	
encode Governorate, gen(gov)
	replace gov = 0 if gov == 1
	replace gov = 1 if gov == 2
	label drop gov
	label define gov 0 "Irbid" 1 "Mafraq"
	label val gov gov

gen female_endline = (gender==2) if gender!=.
gen female_hoh=(hoh==1 & gender==2) if gender!=. & hoh!=.
	replace female_hoh=1 if hoh==0 & q404_1==2

egen agecat_endline = cut(q202a), at(18,30,40,50,60,70,85)

*-------------------------------------------------------------------------------
* REGRESSIONS + CREATE BALANCE TABLE 
*-------------------------------------------------------------------------------

gl controls female_endline agecat_endline married DisabilityLevel3 /// 
	DependencyRatio hhsize_baseline Families n_children_baseline /// 
	piped_water roof windows floor toilet_baseline stayshelter /// 
	rent_baseline_ppp lease_contract changeshelter shelter_type
				
foreach y in $controls {	
	reg `y' assign_flex /*[pw=weightps]*/, r cl(locality)
	tempname M
	mat `M' = r(table)		
	mat list `M'
		loc b_`y'  = string(`M'[1,1], "%15.2fc") 
		loc se_`y' = string(`M'[2,1], "%12.2fc")
		loc p_`y'  = string(`M'[4,1], "%12.2fc")
		loc `T'_star_`y'=cond(`p_`y''<=.01,"***",cond(`p_`y''<=.05,"**",cond(`p_`y''<=.1,"*","")))
		loc N_`y' = string(e(N), "%15.0fc")
		su `y' if assign_flex==0 & e(sample)
		loc mean_c_`y'= string(r(mean), "%12.2fc")
		su `y' if assign_flex==1 & e(sample)
		loc mean_t_`y'= string(r(mean), "%12.2fc")
}
	
reg assign_flex $controls, r cl(locality)
test $controls
	loc F= string(r(p), "%12.3fc")
	
loc lab_female_endline       "Female respondent (=1)"
loc lab_agecat_endline       "Age (categorical)"
loc lab_married              "Married (=1)"
loc lab_DisabilityLevel3     "Disabled (Washington Group, =1)"

loc lab_DependencyRatio      "Dependency Ratio"
loc lab_hhsize_baseline      "Household size"
loc lab_Families             "Number of families in the same house"
loc lab_n_children_baseline  "Number of children" 

loc lab_piped_water          "Access to piped water (=1)"
loc lab_roof                 "Fully constructed roof (=1) "
loc lab_windows              "Functional windows (=1) "
loc lab_floor                "Completed floor (=1)"
loc lab_toilet_baseline      "Toilet (=1)"
loc lab_stayshelter          "Plan to stay in shelter (=1) "
loc lab_rent_baseline_ppp    "Monthly rent (USD PPP)"
loc lab_lease_contract       "Lease contract (=1) "
loc lab_changeshelter        "Number of times moved shelter"
loc lab_shelter_type         "Permanent shelter (=1)"

* Panel A: Respondent Characteristics 
cap file close fh
file open fh using "$dtab/balance1.tex", replace write
local q = 0
foreach y in female_endline agecat_endline married DisabilityLevel3 {
	local q = `q' + 1
	file write fh "(`q')  & `lab_`y'' & `mean_t_`y'' & `mean_c_`y''	 & `b_`y''`_star_`y'' & (`se_`y'') &  `N_`y'' \\  " _n
}
file close fh
project, creates("$dtab/balance1.tex") preserve

* Panel B: Household Characteristics
cap file close fh 
file open fh using "$dtab/balance2.tex", replace write
foreach y in DependencyRatio hhsize_baseline Families n_children_baseline {
	local q = `q' + 1
	file write fh "(`q')  & `lab_`y'' & `mean_t_`y'' & `mean_c_`y''	 & `b_`y''`_star_`y'' & (`se_`y'') &  `N_`y'' \\  " _n
}
file close fh
project, creates("$dtab/balance2.tex") preserve

* Panel C: Shelter Characteristics
cap file close fh 
file open fh using "$dtab/balance3.tex", replace write
foreach y in piped_water roof windows floor toilet_baseline stayshelter /// 
				rent_baseline_ppp lease_contract changeshelter shelter_type  {
	local q = `q' + 1
	file write fh "(`q')  & `lab_`y'' & `mean_t_`y'' & `mean_c_`y''	 & `b_`y''`_star_`y'' & (`se_`y'') &  `N_`y'' \\  " _n
}
file write fh " & \textit{Joint significance p-val:} `F' \\" _n
file close fh
project, creates("$dtab/balance3.tex") preserve
