import numpy as np
import pandas as pd
import matplotlib.pyplot as plt
import os
from dotenv import load_dotenv

# Load environment variables (see README.md for instructions on setting up the .env file)
load_dotenv()

# Get data path
DATA_PATH = os.getenv('DATA_PATH')


def plot_distributions(simulated_beta_hat, simulated_mean_forecast,differences):
    """
    Plot distributions and differences with statistics.
    Parameters:
    - simulated_beta_hat (array): Simulated beta hat values.
    - simulated_mean_forecast (array): Simulated mean forecast values.
    - differences (array): Differences between beta hat and mean
    forecast.
    This function creates two subplots:
    - Subplot 1: Distributions of beta_hat and mean_forecast.
    - Subplot 2: Distribution of differences with mean, lower bound,
    and upper bound.
    It also adds vertical lines for mean difference, lower bound, and
    upper bound.
    """
    # Calculate the mean, lower bound, and upper bound of differences
    mean_diff = np.mean(differences)
    lower_bound = np.percentile(differences, 2.5)
    upper_bound = np.percentile(differences, 97.5)
    # Create subplots
    plt.figure(figsize=(12, 6))
    # Subplot 1: Distributions of beta_hat and mean_forecast
    plt.subplot(1, 2, 1)
    plt.hist(simulated_beta_hat.ravel(), bins=30, alpha=0.5,
    label='Beta Hat')
    plt.hist(simulated_mean_forecast.ravel(), bins=30, alpha=0.5,
    label='Mean Forecast')
    plt.xlabel('Value')
    plt.ylabel('Frequency')

    plt.title('Distributions of Beta Hat and Mean Forecast')
    plt.legend()
    # Subplot 2: Distribution of differences
    plt.subplot(1, 2, 2)
    plt.hist(differences, bins=30, alpha=0.5, label='Differences')
    plt.xlabel('Value')
    plt.ylabel('Frequency')
    plt.title('Distribution of Differences')
    plt.axvline(mean_diff, color='red', linestyle='dashed',
    linewidth=2, label=f'Mean Difference: {mean_diff:.2f}')
    plt.axvline(lower_bound, color='green', linestyle='dashed',
    linewidth=2, label=f'Lower Bound: {lower_bound:.2f}')
    plt.axvline(upper_bound, color='blue', linestyle='dashed',
    linewidth=2, label=f'Upper Bound: {upper_bound:.2f}')
    plt.legend()
    # Display the plots
    plt.tight_layout()
    plt.show()


def simulate_and_test_equalities(beta_hat, se_beta_hat, mean_forecast_mean, mean_forecast_sd, percentile_10, percentile_90, n_actual, n_prediction, num_simulations, alpha=0.05):
    """
    Simulate two distributions, plot them, and test the null
    hypothesis.
    Parameters:
    - beta_hat (float): Estimated beta hat value.
    - se_beta_hat (float): Standard error of beta hat.
    - mean_forecast_mean (float): Mean of mean forecast.
    - mean_forecast_sd (float): Standard deviation of mean forecast.
    - percentile_10 (float): 10th percentile of mean forecast.
    - percentile_90 (float): 90th percentile of mean forecast.
    - n_actual (int): Number of observations for the actual
    distribution.
    - n_prediction (int): Number of observations for the forecast
    distribution.
    - num_simulations (int): Number of simulations.
    - alpha (float): Significance level for hypothesis testing.
    This function simulates two distributions, plots them, and tests
    the null hypothesis.
    It creates two subplots with distributions and differences,
    including mean, lower bound, and upper bound.
    The function then tests if zero is within the confidence interval
    and returns the test result.
    """
    # Simulate beta hat values based on a normal distribution
    simulated_beta_hat = np.random.normal(beta_hat, se_beta_hat,
    (num_simulations))
    # Calculate the standard error (SE) of the mean forecast
    se_mean_forecast = mean_forecast_sd / np.sqrt(n_prediction)
    # Simulate mean forecast values based on a normal distribution
    simulated_mean_forecast = np.random.normal(mean_forecast_mean,
    se_mean_forecast, (num_simulations))
    # Calculate the differences for all simulations
    differences = simulated_beta_hat - simulated_mean_forecast
    # Plot the distributions and differences
    plot_distributions(simulated_beta_hat, simulated_mean_forecast,
    differences)
    # Calculate the mean, lower bound, and upper bound of differences
    mean_diff = np.mean(differences)
    lower_bound = np.percentile(differences, 2.5)
    upper_bound = np.percentile(differences, 97.5)
    # Test if zero is within the confidence interval
    if (lower_bound <= 0) & (0 <= upper_bound):
        return "Fail to reject the null hypothesis"
    else:
        return "Reject the null hypothesis"

outcomes_df = pd.read_csv(os.path.join(DATA_PATH, "analysis","means_coefs_A.csv"))
outcomes2_df = pd.read_csv(os.path.join(DATA_PATH, "analysis","means_coefs_B.csv"))

actual_df = outcomes_df.iloc[0:8,1:].sort_values(by='var_name').reset_index().drop('index', axis=1)
prediction_df = outcomes_df.iloc[8:,1:].sort_values(by='var_name').reset_index().drop('index', axis=1)

outcome1_result = simulate_and_test_equalities(beta_hat = actual_df['Mean'][0], se_beta_hat = actual_df['se'][0],
mean_forecast_mean=prediction_df['Mean'][0], mean_forecast_sd =
prediction_df['se'][0],
percentile_10 =
prediction_df['Percentile_10'][0], percentile_90 =
prediction_df['Percentile_90'][0],
n_actual = 1395,
n_prediction = 61, num_simulations = 1000, alpha=0.05)

outcome1_result

for index in range(len(actual_df)):
    var_name = actual_df['var_name'][index]
    beta_hat = actual_df['Mean'][index]
    se_beta_hat = actual_df['se'][index]
    mean_forecast_mean = prediction_df['Mean'][index]
    mean_forecast_sd = prediction_df['se'][index]
    percentile_10 = prediction_df['Percentile_10'][index]
    percentile_90 = prediction_df['Percentile_90'][index]
    n_actual = 1395
    n_prediction = 61
    num_simulations = 1000
    alpha = 0.05
    result = simulate_and_test_equalities(beta_hat=beta_hat,se_beta_hat=se_beta_hat,
    mean_forecast_mean=mean_forecast_mean,
    mean_forecast_sd = mean_forecast_sd,
    percentile_10=percentile_10,
    percentile_90=percentile_90,
    n_actual=n_actual,
    n_prediction=n_prediction,
    num_simulations=num_simulations,
    alpha=alpha
    )
    print(f"Result for {var_name}: {result}")

# For Panel B
actual_df = outcomes2_df.iloc[0:3,1:].sort_values(by='var_name').reset_index().drop('index', axis=1)
prediction_df = outcomes2_df.iloc[3:,1:].sort_values(by='var_name').reset_index().drop('index', axis=1)



outcome1_result = simulate_and_test_equalities(beta_hat = actual_df['Mean'][0], se_beta_hat = actual_df['se'][0],
mean_forecast_mean=prediction_df['Mean'][0], mean_forecast_sd =
prediction_df['se'][0],
percentile_10 =
prediction_df['Percentile_10'][0], percentile_90 =
prediction_df['Percentile_90'][0],
n_actual = 1395,
n_prediction = 61, num_simulations = 1000, alpha=0.05)

outcome1_result

for index in range(len(actual_df)):
    var_name = actual_df['var_name'][index]
    beta_hat = actual_df['Mean'][index]
    se_beta_hat = actual_df['se'][index]
    mean_forecast_mean = prediction_df['Mean'][index]
    mean_forecast_sd = prediction_df['se'][index]
    percentile_10 = prediction_df['Percentile_10'][index]
    percentile_90 = prediction_df['Percentile_90'][index]
    n_actual = 1395
    n_prediction = 61
    num_simulations = 1000
    alpha = 0.05
    result = simulate_and_test_equalities(beta_hat=beta_hat,se_beta_hat=se_beta_hat,
    mean_forecast_mean=mean_forecast_mean,
    mean_forecast_sd = mean_forecast_sd,
    percentile_10=percentile_10,
    percentile_90=percentile_90,
    n_actual=n_actual,
    n_prediction=n_prediction,
    num_simulations=num_simulations,
    alpha=alpha
    )
    print(f"Result for {var_name}: {result}")

